@@ -1,5 +1,5 @@
 # (C) Copyright 1996- ECMWF.
-# 
+#
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 # In applying this licence, ECMWF does not waive the privileges and immunities
@@ -8,8 +8,8 @@
 
 from typing import Dict
 
-from .trigger import TriggerType, Trigger
 from .. import logger
+from .trigger import Trigger, TriggerType
 
 
 class TriggerFactory:
